
######################################
# FILE: DEFINING THE PARETO FRONTIER #
######################################

rm(list = ls())
wd= dirname(rstudioapi::getActiveDocumentContext()$path)
setwd(substr(wd,1,nchar(wd)-nchar(basename(wd))-1))

listofpackages = c("ggplot2", "matlab","readxl","dplyr","gtools","rJava","xlsx")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

###INITIAL PARAMENTERS TO BE SET HERE###

#Uncomment the region of interest:
#Region=1  #: LOMBARDIA
#Region=2   #: VENETO

Policy=1024 #: Policy used for Pareto

#Uncomment the biological parameters to be used. Possible values:
#Bio_Parm = "CDC_mean"
#Bio_Parm="Ferguson"  #Default parameters used in the paper
bio=c(Ferguson="",CDC_mean="_CDC")

#Define the beta(m) parameter to be used from September 1 (start of simulation period):
#bm_Sim = 0.7
#bm_Sim = 0.9
#Define T_inf to be used from September 1 (start of simulation period):
TINF1=0

######### End of parameters setting

#Time variables:
TimeHoriz = 306+364  #(Starting time variable: January 1 2020. Default ending period: Semptember 1 2021)
time = c(1:TimeHoriz)

TotDeltaEffFATMat = matrix(data = NA, nrow = TimeHoriz, ncol = 5)  
CDlogLOSSMat = matrix(data = NA, nrow = 1, ncol = 5)  
CDexaLOSSMat = matrix(data = NA, nrow = 1, ncol = 5)  
TotEffFATMat = matrix(data = NA, nrow = 1, ncol = 5)  
TotEffFATMat_4May = matrix(data = NA, nrow = 1, ncol = 5)  

#Preparation of the policy matrix 

Policies=permutations(n = 2, r = 10, v = c(0.6,1),repeats.allowed = TRUE)

Outcome      = matrix(data = NA, nrow = dim(Policies)[1], ncol = 12)  #dim(Policies)[1]
Data         = matrix(data = NA, nrow =dim(Policies)[1], ncol = 15);  # dim(Policies)[1]

for (kk in 1:dim(Policies)[1]){  #
  source("Code/SEIR_HC_SEC_AGE.R")
  Outcome[kk,] = c(TotalDead, GDPLoss ,alpha[,TimeHoriz])
  AvgRZeroSeparAct = t(FracPopSec)%*%R[[TimeHoriz-1]]%*%FracPopSec;
  TotRec = sum(REC);
  HerdImm = TotRec[TimeHoriz]/N[TimeHoriz]
  
  Data[kk,]   = c(TotalDead, GDPLoss, AvgRZeroSeparAct,  HerdImm,TotalDeadYr, alpha[,TimeHoriz])
  print(kk)
}


class(Data)  = "numeric"
DataOrdF     = Data[order(-Data[,1]),]
K            = dim(DataOrdF)[2]
NormTotalFat = (DataOrdF[,1])/max(DataOrdF[,1])
TotalGDPLoss = DataOrdF[,2]
dh           = 0.01 #0
RangeLambda  = round(1/dh);
Optimal      = matrix(data = NA, nrow =2, ncol =RangeLambda+1); 
lambda       = matrix(data = NA, nrow =1, ncol =RangeLambda+1);

for (i in 1:(RangeLambda+1)){
  lambda[i] = (i-1)*dh;
  DataOrdF  =cbind(DataOrdF,  (i-1)*dh*NormTotalFat   +(1-(i-1)*dh)*TotalGDPLoss);  
  Optimal[1,i] =max(-DataOrdF[,K+i]) 
  Optimal[2,i] = which.max(-DataOrdF[,K+i])
  print(i)
}

ShDataOrdF        = DataOrdF[,1:15];
EPI               = t(unique(Optimal[2,]))
EfficientPolicies = ShDataOrdF[EPI,]
dati<-as.data.frame(EfficientPolicies)
colnames(dati)    = c("TotalDead", "GDPLoss", "AvgRZeroSeparAct", "HerdImm", "TotalDeadYr",
                    "alpha1","alpha2","alpha3","alpha4","alpha5","alpha6","alpha7","alpha8","alpha9","alpha10")

AGE     =c(as.numeric(subset(Data, Data[,6]==1 & Data[,7]==1 & Data[,8]==1 & Data[,9]==0.6 & Data[,10]==0.6 &      Data[,11]==1 & Data[,12]==1 & Data[,13]==1 & Data[,14]==0.6 & Data[,15]==0.6)))       #,"1110.60.61110.60.6",efficient=0)
SEC_AGE =c(as.numeric(subset(Data, Data[,6]==1 & Data[,7]==1 & Data[,8]==1 & Data[,9]==0.6 & Data[,10]==0.6 &      Data[,11]==1 & Data[,12]==0.6 & Data[,13]==0.6 & Data[,14]==0.6 & Data[,15]==0.6)))   #,"1110.60.610.60.60.60.6",efficient=0)
SEC     =c(as.numeric(subset(Data, Data[,6]==1 & Data[,7]==1 & Data[,8]==1 & Data[,9]==1 & Data[,10]==1     &      Data[,11]==0.6 & Data[,12]==0.6 & Data[,13]==0.6 & Data[,14]==0.6 & Data[,15]==0.6))) #,"111110.60.60.60.60.6",efficient=0)

dati$code=paste(dati[,6],dati[,7],dati[,8],dati[,9],dati[,10],dati[,11],dati[,12],dati[,13],dati[,14],dati[,15], sep ="")

eff=c(0,0,0)
if ("111110.60.60.60.60.6" %in% dati$code){ 
  print("SEC is efficient")
  eff[1]="SEC"
}else{ dati=rbind(dati,SEC)}
if ("1110.60.610.60.60.60.6" %in% dati$code){  
  print("SEC_AGE is efficient")
  eff[2]="SEC_AGE" 
}else{ dati=rbind(dati,SEC_AGE)}
if ("1110.60.61110.60.6" %in% dati$code){ 
  print("AGE is efficient")
  eff[2]="AGE"
}else{ dati=rbind(dati,AGE)}

dati2=(dati[,-c(16,17)])

dati3=dati2

if (Region==1){
  write.xlsx(dati3, paste("Data/DATI_LOM_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
  write.xlsx(eff, paste("Data/EFF_LOM_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
  print(paste("Data/DATI_LOM_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
}else if (Region==2){
  write.xlsx(dati3, paste("Data/DATI_VEN_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
  write.xlsx(eff, paste("Data/EFF_VEN_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
  print(paste("Data/DATI_VEN_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".xlsx",sep = ""))
}

#END