
#######################################
# SETUP: CDC WITH BEHAVIORAL RESPONSE #
#######################################

#Note: some parameters are setted in the plot figures files

#Choice of model dimensions: 
L                  = 5        # number of age blocks 
AgeSectors         = 3*L      # Low Risk, High Risk, Inactive
Age_Groups         = 3*L+9-L  # Working Age (3*L) + 9-L non-working age
LabShare =0.65                # Cobb-Douglas PF parameter 

#timing
TimeStartLockD          =  68  # March 8
May4                    = 125
May18                   = 139
June1                   = 153
June20                  = 172
Sept1                   = 245
Sept14                  = 258
Oct23                   = 297
Nov1                    = 306
if (Policy==0){
  TimeStartNewPolicy    = TimeHoriz #to calibrate the model we must not consider the post-lockdown period
}else{ 
  TimeStartNewPolicy    = Nov1   
} 

#Set initial population and initial infected
if (Region==1){ 
  NInfInit  = 10
  NInit     = 10000000
}else if (Region==2){
  NInfInit  = 5
  NInit     = 4900000
}

#------------------------------#
#### Calibration of Parameters
if (Region == 1) { # Lombardia 
   Tr_0         = 2.28# 
 }else if (Region==2){ #veneto  
   Tr_0         = 1.98
  }
#------------------------------#

## Load regional parameters of IC capacity
ICU_Lomb_Ven = read_excel("Data/ICU_Lomb_Ven.xlsx")

if (Region == 1){ 
  ICC       = as.ts(ICU_Lomb_Ven[1:TimeHoriz ,2]) 
} else if (Region == 2) {
  ICC       = as.ts(ICU_Lomb_Ven[1:TimeHoriz ,3])
} 

## variables Demographics + Labor participation
if (Region == 1)  {#LOMBARDIA
            #   0- 9  10-19  20-29  30-39  40-49  50-59  60-69  70-79  80+
  FracPop  = c(0.088, 0.094, 0.098, 0.118, 0.158, 0.156, 0.118, 0.099, 0.071)      
  Part     =               c(0.494, 0.771, 0.832, 0.804, 0.474) #istat 
  Part[5]  = Part[5]/2 #to account for retirement
}else if (Region == 2){ #VENETO
  FracPop  = c(0.085, 0.096, 0.098, 0.111, 0.156, 0.161, 0.122, 0.099, 0.071)
  Part     =               c(0.497, 0.751, 0.826, 0.794, 0.467) #istat 
  Part[5]  = Part[5]/2 #to account for retirement
}
WorkersFrac     = FracPop[3:7]

## Risky sector
FreqHighRisk    = 0.3993 
FreqLowRisk     = 1-FreqHighRisk

## 
MRiskPart       = cbind(Part*FreqLowRisk, Part*FreqHighRisk, 1-Part) 
WorkersTypFrac  = diag(WorkersFrac)%*%MRiskPart
vWorkersTypFrac = reshape(WorkersTypFrac,c(3*L,1))
FracPopSec      =c(FracPop[1:2], vWorkersTypFrac, FracPop[(7+1):9])

## Biological parameters CDC
if (Bio_Parm=="CDC_mean"){                  
bPrSev          = c(0.0205,	 0.0205,	0.174,	0.174,	0.2075,	0.237,  0.27775, 0.34725, 0.403)
bPrFat          = c(0.000001,      0.000001,	      0.0015,	0.0015,	0.004,	0.01325, 0.029,	 0.056,	  0.074)
bPrIC           = c(0.000001,	     0.000001,	      0.031,	0.031,	0.055,	0.07925, 0.107,  0.171,	0.2075) 
}else if(Bio_Parm=="Ferguson"){
bPrFat          = c(0.00002, 0.00006, 0.0003, 0.0008, 0.0015, 0.006, 0.022, 0.051, 0.093)
bPrSev          = c(0.001,   0.003,   0.012,  0.032,  0.049,  0.102, 0.166, 0.243, 0.273) 
bPrIC           = c(0.05,    0.05,    0.05,   0.05,   0.063,  0.122, 0.274, 0.432, 0.709)
}

## Extend Biological parameters to extended Age_Groups
PrFat  = c(bPrFat[1:2], bPrFat[3:7], bPrFat[3:7], bPrFat[3:7], bPrFat[8:9]) 
PrSev  = c(bPrSev[1:2], bPrSev[3:7], bPrSev[3:7], bPrSev[3:7], bPrSev[8:9]) 
PrIC   = c( bPrIC[1:2],  bPrIC[3:7],  bPrIC[3:7],  bPrIC[3:7],  bPrIC[8:9]) 
PrMild = 1-PrSev-PrFat

#------------------------------#
#Set logistic parameters 
if (Region==1){ 
   k_1=2000
   k_0=0.0008
}else if (Region==2){
  k_1=800
  k_0=0.0008
}

#Define delta and gamma 
delta=matrix(NA, nrow = TimeHoriz, ncol=1)
if (Region == 1){
  delta[1:68]=0.3
  delta[68:TimeHoriz]=0.7
} else if (Region == 2){
  delta[1:TimeHoriz]=0.7
}

gamma=0.1
#------------------------------#

##time parameters##

sigmaInf     = 1/2.9
Tinf1=c(rep(0,Nov1-1),rep(TINF1,TimeHoriz-Nov1))
sigmaInfTest = 1/(2.9-Tinf1)
sigmaInc     = 1/5.2

sigmaSdSHosp = 1/(17.8-5) 
sigmaSHosp   = 1/5
sigmaShdInf  = 1/(22.6-5)
sigmaSHospU=1/5
sigmaSHospD=1/5
###
sigmaSrecU    = 1/11.1
sigmaSrecD   = 1/11.1 
PrM2SevU= gamma*PrSev
PrM2SevD=0
sigmaHospIC  = 1/3
sigmaSdHospIc=1/(17.8-3-5)
sigmaShdHospIc=1/(22.6-3-5)
sigmaShdSHosp=1/(22.6-5)
sigmaIcRec=1/7

# Functions
Oliver <- function(x) {(sign(x)^2 + sign(x)) / 2} #indicator function used in the loop


#Temperature setting#
if (Region == 1){
  tempM=c(3.8,8.1, 9.5,15, 19.7, 22, 25 ,25.3,20.6, 13.5, 9.4, 6.1)
} else if (Region == 2){
  tempM=c(3.3,	7.2,	9.3,	14.5,	18.7,	21.7,	24.5,	25.3, 20.3, 13.1, 10.1, 5.4)
}


tempM = tempM - tempM[1]
temp=c(rep(tempM[1],31),
       rep(tempM[2],29),
       rep(tempM[3],31),
       rep(tempM[4],30),
       rep(tempM[5],31),
       rep(tempM[6],30),
       rep(tempM[7],31),
       rep(tempM[8],31),
       rep(tempM[9],30),
       rep(tempM[10],31),
       rep(tempM[11],30),
       rep(tempM[12],31),#
       rep(tempM[1],31),
       rep(tempM[2],28),
       rep(tempM[3],31),
       rep(tempM[4],30),
       rep(tempM[5],31),
       rep(tempM[6],30),
       rep(tempM[7],31),
       rep(tempM[8],31),
       rep(tempM[9],30),
       rep(tempM[10],31),
       rep(tempM[11],30),
       rep(tempM[12],31),#
       rep(tempM[1],31),
       rep(tempM[2],28),
       rep(tempM[3],31),
       rep(tempM[4],30),
       rep(tempM[5],31),
       rep(tempM[6],30),
       rep(tempM[7],31),
       rep(tempM[8],31),
       rep(tempM[9],30),
       rep(tempM[10],31),
       rep(tempM[11],30),
       rep(tempM[12],31)
)


### Behavioural Parameters from Mobility analysis####
#note that Vbar, LOM ,LOCK, PHASE2, TEMP are taken by the regression output of Mobility_analysis.R

if (Region == 1){
  Vbar =725.6+85 
  bm=c(rep(1,TimeStartLockD-1),rep(0.95,May4-TimeStartLockD), rep(0.54,Sept1-May4), rep(0.59, 2), rep(0.60, 2), rep(0.60, 2), rep(0.60, 2), rep(0.61, 2), rep(0.64, 2), rep(0.67, 2), rep(0.7,Nov1-Sept1+13), rep(bm_Sim,TimeHoriz-Nov1))
  
} else if (Region == 2){
  Vbar = 725.6    
  bm=c(rep(1,TimeStartLockD-1),rep(0.8,May4-TimeStartLockD), rep(0.6,Sept1-May4), rep(0.64, 2), rep(0.67, 2), rep(0.70, 2), rep(0.70, 2), rep(0.70, 2), rep(0.70, 2), rep(0.70, 2), rep(0.7,Nov1-Sept1+13), rep(bm_Sim,TimeHoriz-Nov1))
}


LOCK= 200 
PHASE2=55.4 
TEMP=-0.0396 

#END