
#########################
#   MOBILITY ANALYSIS   #
#########################

rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

listofpackages = c("gplots","readr","foreign","readstata13", "zoo","multigroup","pracma", "matlab","dplyr","ggplot2","readxl", "minpack.lm")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}
Sys.setlocale("LC_TIME", "English")
temp_lom=c(3.8,8.1, 9.5,15, 19.7, 22, 25 ,25.3,20.6, 13.5, 9.4, 6.1)
temp_ven=c(3.3,	7.2,	9.3,	14.5,	18.7,	21.7,	24.5,	25.3, 20.3, 13.1, 10.1, 5.4)

data=read.csv2("Data/MOBILITY_ANALYSIS.csv")
data$date=as.Date(data$date)
# dummies for calendar
data$dow =  weekdays(data$date)

data$sunday = rep(0, length(data$date))
data$sunday[data$dow == "Sunday"] = 1

data$easter = rep(0, length(data$date))
data$easter[data$date == "2020-04-12"] = 1
data$easter[data$date == "2020-04-13"] = 1

data$apr25 = rep(0, length(data$date))
data$apr25[data$date == "2020-04-25"] = 1

data$may1 = rep(0, length(data$date))
data$may1[data$date == "2020-05-01"] = 1

data$jun2 = rep(0, length(data$date))
data$jun2[data$date == "2020-06-02"] = 1

data$start = rep(0, length(data$date))
data$start[data$date < "2020-03-08"] = 1

data$lock = rep(0, length(data$date))
data$lock[data$date >= "2020-03-08" & data$date <= "2020-05-03"] = 1

data$phase2 = rep(0, length(data$date))
data$phase2[data$date >= "2020-05-04"] = 1

data$G_workplaces=data$G_workplaces/100
data$G_grocery=data$G_grocery/100
data$G_transit=data$G_transit/100
data$G_work_trans_groc = (data$G_workplaces + data$G_grocery + data$G_transit)/ 3


# Protezione Civile
#Note: for some regions nuovi_positivi has some negative values due to 
#problems in reporting. This is not the case for Lombardia and Veneto.
#data$P_nuovi_positivi = ave(data$P_nuovi_positivi, data$region, FUN=function(x) c( (lag(x,1) + lead(x,1))/2) )
data$P_nuovi_positivi[data$date < "2020-02-24"] = 0
data$npos_t = data$P_nuovi_positivi

data$P_deceduti[data$date < "2020-02-24"] = 0
data$c_fat_t = data$P_deceduti
data$fat_t = ave(data$c_fat_t, data$region, FUN=function(x) c( x-lag(x,1)) )

data <- subset(data, date >= "2020-02-15")

data$lom = rep(0, length(data$date))
data$lom[data$region == "lombardia"] = 1

data$ven = rep(0, length(data$date))
data$ven[data$region == "veneto"] = 1

data$lomven = rep(0, length(data$date))
data$lomven[data$region == "lombardia" | data$region == "veneto"] = 1

#BEHAVIORAL RESPONSE USING DAILY FATALITIES (TABLE IN THE PAPER)

data_nl = subset(data, lomven == 1)
data_nl$fat_t[1]=0
data_nl = data_nl[!is.na(data_nl$G_grocery),]
data_nl = data_nl[data_nl$date <= "2020-10-23",]  #We restricted the dataset to keep the same dates used in the paper 
                                                  #regression allowing a replication. Comment this line for using the 
                                                  #whole updated dataset. 
data_nl = data_nl[data_nl$date >= "2020-02-25",] 
###temperature
data_nl$temperature=0
data_nl$temperature[data_nl$date >= "2020-01-01"& data_nl$region=="lombardia"]=temp_lom[1] - temp_lom[1] 
data_nl$temperature[data_nl$date >= "2020-02-01"& data_nl$region=="lombardia"]=temp_lom[2] - temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-03-01"& data_nl$region=="lombardia"]=temp_lom[3]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-04-01"& data_nl$region=="lombardia"]=temp_lom[4]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-05-01"& data_nl$region=="lombardia"]=temp_lom[5]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-06-01"& data_nl$region=="lombardia"]=temp_lom[6]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-07-01"& data_nl$region=="lombardia"]=temp_lom[7]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-08-01"& data_nl$region=="lombardia"]=temp_lom[8]- temp_lom[1]
data_nl$temperature[data_nl$date >= "2020-09-01"& data_nl$region=="lombardia"]=temp_lom[9]- temp_lom[1]

data_nl$temperature[data_nl$date >= "2020-01-01"& data_nl$region=="veneto"]=temp_ven[1] -temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-02-01"& data_nl$region=="veneto"]=temp_ven[2]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-03-01"& data_nl$region=="veneto"]=temp_ven[3]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-04-01"& data_nl$region=="veneto"]=temp_ven[4]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-05-01"& data_nl$region=="veneto"]=temp_ven[5]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-06-01"& data_nl$region=="veneto"]=temp_ven[6]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-07-01"& data_nl$region=="veneto"]=temp_ven[7]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-08-01"& data_nl$region=="veneto"]=temp_ven[8]-temp_ven[1]
data_nl$temperature[data_nl$date >= "2020-09-01"& data_nl$region=="veneto"]=temp_ven[9]-temp_ven[1]


############
#    NLS   #
############

paramL=c(A=0, B=0, LOCK=0, PHASE2=0, B_1=-0, VBAR=5, LOM = 0, SUN = 0, EAST=0, APR25=0, MAY1=0, JUN2=0)
reg0 = nlsLM(G_grocery ~ A + B*( fat_t + (1 + B_1*temperature)*(LOCK*lock + PHASE2*phase2))/(fat_t + 
                         +(1 + B_1*temperature)*(VBAR + LOM*lom + SUN*sunday + EAST*easter +
                                                  +APR25*apr25 + MAY1*may1 +JUN2*jun2)),
                        data=data_nl, start=paramL)
summary(reg0)


paramL=c(A=0, B=0, LOCK=0, PHASE2=0, B_1=-0, VBAR=5, LOM = 0, SUN = 0, EAST=0, APR25=0, MAY1=0, JUN2=0)
reg1 = nlsLM(G_work_trans_groc ~ A + B*( fat_t + (1 + B_1*temperature)*(LOCK*lock + PHASE2*phase2))/(fat_t + 
                                                                                               +(1 + B_1*temperature)*(VBAR + LOM*lom + SUN*sunday + EAST*easter +
                                                                                                                         +APR25*apr25 + MAY1*may1 +JUN2*jun2)),
             data=data_nl, start=paramL)
summary(reg1)
data_nl$hat_G_work_trans_groc = coef(reg1)[1] + coef(reg1)[2]*(data_nl$fat_t + (coef(reg1)[3]*data_nl$lock + coef(reg1)[4]*data_nl$phase2)*(1+coef(reg1)[5]*data_nl$temperature))/(data_nl$fat_t + (coef(reg1)[6] + coef(reg1)[7]*data_nl$lom)*(1+coef(reg1)[5]*data_nl$temperature))  



#############
#  LOWESS   #
#############

df_prelock=subset(data_nl,start==1)
prelocke=lowess(G_work_trans_groc~fat_t , data=df_prelock,f=0.5)
prelock=loess(G_work_trans_groc~fat_t , data=df_prelock,control = loess.control(surface = "direct"))

df_lock=subset(data_nl,lock==1)
locke=lowess(G_work_trans_groc~fat_t , data=df_lock,f=0.5)
lock=loess(G_work_trans_groc~fat_t , data=df_lock,control = loess.control(surface = "direct"))
lock_predicted=predict(lock)

df_postlock=subset(data_nl,phase2==1)
postlocke=lowess(G_work_trans_groc~fat_t , data=df_postlock,f=0.5)
postlock=loess(G_work_trans_groc~fat_t , data=df_postlock)


qplot()+
  geom_line(aes(x=postlock$x,y=postlock$fitted),col="red")+
  geom_line(aes(x=postlock$x[df_postlock$sunday==0 | df_postlock$easter==0  | df_postlock$apr25==0 | df_postlock$may1==0 | df_postlock$jun2==0],y=df_postlock$hat_G_work_trans_groc[df_postlock$sunday==0 | df_postlock$easter==0  | df_postlock$apr25==0 | df_postlock$may1==0 | df_postlock$jun2==0]),col="red",linetype="dashed")+
  geom_point(data=df_postlock,aes(fat_t,G_work_trans_groc),col="red",shape=2)+
  
  geom_line(aes(x=prelock$x,y=prelock$fitted),col="black")+
  geom_line(aes(x=prelock$x[df_prelock$sunday==0 | df_prelock$easter==0  | df_prelock$apr25==0 | df_prelock$may1==0 | df_prelock$jun2==0],y=df_prelock$hat_G_work_trans_groc[df_prelock$sunday==0 | df_prelock$easter==0  | df_prelock$apr25==0 | df_prelock$may1==0 | df_prelock$jun2==0] ),col="black", linetype="dashed")+
  geom_point(data=df_prelock, aes(fat_t,G_work_trans_groc),col="black",shape=1)+
  
 
  geom_line(aes(x=lock$x,y=lock$fitted),col="blue")+
  geom_line(aes(x=lock$x[df_lock$sunday==0 | df_lock$easter==0  | df_lock$apr25==0 | df_lock$may1==0 | df_lock$jun2==0],y=df_lock$hat_G_work_trans_groc[df_lock$sunday==0 | df_lock$easter==0  | df_lock$apr25==0 | df_lock$may1==0 | df_lock$jun2==0]),col="blue",linetype="dashed")+
  geom_point(data=df_lock,aes(fat_t,G_work_trans_groc),col="blue",shape=0)+
  
  scale_y_continuous(breaks=seq(-1,0,.25), minor_breaks =seq(-1,0,.25), limits = c(-1,0))+
  scale_x_continuous(breaks=seq(0,1000,50), minor_breaks =seq(0,1000,50) , limits = c(0,550))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  theme_bw()+
  labs(title = "", x = "Daily fatalities", y = "Average change of mobility") 

ggsave("graphs/MOBILITY/LOWESS.png", width = 8, height = 5)


#GRAPH WITH DOUBLE AXIS: DAILY FATALITIES AND MOBILITY

Lombardia = subset(data, region == "lombardia")
Veneto = subset(data, region == "veneto")
X_lim = 300 #to restrict the graph to the first x values 
maggio4 = Lombardia$date[80]
marzo8  = Lombardia$date[23]

colors <- c("Mobility" = "blue", "Fatalities"="red")

p <- ggplot() +
  geom_line(aes(x = Lombardia$date[11:300],y = Lombardia$G_work_trans_groc[11:300],color="Mobility"), size = 0.75)+
  geom_vline(xintercept=marzo8-35, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-28, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-21, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-14, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-7, linetype="dashed",color="grey")+ 
    geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=marzo8+7, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*2, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*3, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*4, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*5, linetype="dotdash",color="grey")+ #pasqua
  geom_vline(xintercept=marzo8+7*5+1, linetype="dotdash",color="grey")+ #pasquetta
  geom_vline(xintercept=marzo8+7*6, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*7-1, linetype="dotdash",color="grey")+ #25 aprile
  geom_vline(xintercept=maggio4-3, linetype="dotdash",color="grey")+ #1 maggio
  geom_vline(xintercept=marzo8+7*7, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*8, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*9, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*10, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*11, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*12, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*13, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*14, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*15, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*16, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*17, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*18, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*19, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*20, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*21, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*22, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*23, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*24, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*25, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*26, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*27, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*28, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*29, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*30, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*31, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*32, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*33, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*34, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*12+2, linetype="dotdash",color="grey")+ #2 giugno
  geom_vline(xintercept=maggio4)+ 
  
   scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks", expand = c(0,0), minor_breaks ="1 weeks")+
  scale_y_continuous()+
  theme_classic()+
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)),
        panel.border = element_rect(colour = "black", fill=NA, size=1))+
  labs(title = "Lombardia", x = "", y = "Mobility", color = "Legend") +
  scale_color_manual(values = colors)

p = p + geom_line(aes(x = Lombardia$date[11:300],y = ((Lombardia$fat_t[11:300]/500) -1 ),color="Fatalities"), size = 0.75, linetype = "dashed") 

p <- p + scale_y_continuous(sec.axis = sec_axis(~(.+1)*500, name = "Fatalities"))
p
ggsave("graphs/MOBILITY/MOBILITY_LOM.png", width = 8, height = 5)


#veneto
p <- ggplot() +
  geom_line(aes(x = Veneto$date[11:300],y = Veneto$G_work_trans_groc[11:300],color="Mobility"), size = 0.75)+
  geom_vline(xintercept=marzo8-35, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-28, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-21, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-14, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8-7, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=marzo8+7, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*2, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*3, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*4, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*5, linetype="dotdash",color="grey")+ #pasqua
  geom_vline(xintercept=marzo8+7*5+1, linetype="dotdash",color="grey")+ #pasquetta
  geom_vline(xintercept=marzo8+7*6, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*7-1, linetype="dotdash",color="grey")+ #25 aprile
  geom_vline(xintercept=maggio4-3, linetype="dotdash",color="grey")+ #1 maggio
  geom_vline(xintercept=marzo8+7*7, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*8, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*9, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*10, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*11, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*12, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*13, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*14, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*15, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*16, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*17, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*18, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*19, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*20, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*21, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*22, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*23, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*24, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*25, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*26, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*27, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*28, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*29, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*30, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*31, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*32, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*33, linetype="dashed",color="grey")+ 
  geom_vline(xintercept=marzo8+7*34, linetype="dashed",color="grey")+
  geom_vline(xintercept=marzo8+7*12+2, linetype="dotdash",color="grey")+ #2 giugno
  geom_vline(xintercept=maggio4)+ 
  
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks", expand = c(0,0), minor_breaks ="1 weeks")+
  scale_y_continuous()+
  theme_classic()+
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)),
        panel.border = element_rect(colour = "black", fill=NA, size=1))+
  labs(title = "Veneto", x = "", y = "Mobility", color = "Legend") +
  scale_color_manual(values = colors)

p = p + geom_line(aes(x = Veneto$date[11:300],y = ((Veneto$fat_t[11:300]/70) -0.9 ),color="Fatalities"), size = 0.75, linetype = "dashed") 

p <- p + scale_y_continuous(sec.axis = sec_axis(~(.+0.9)*70, name = "Fatalities"))
p
ggsave("graphs/MOBILITY/MOBILITY_VEN.png", width = 8, height = 5)

