
#####################
# PLOT: CALIBRATION #
#####################

rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
Sys.setlocale("LC_TIME", "English")

listofpackages = c("ggplot2", "matlab","readxl","dplyr","pracma")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

###INITIAL PARAMENTERS TO BE SET HERE###

#Uncomment the region of interest:
#Region=1   #: LOMBARDIA
Region=2  #: VENETO

Policy = 0 #Default policy for calibration: 
           

#Uncomment the biological parameters to be used. Possible values:
Bio_Parm = "CDC_mean"
#Bio_Parm="Ferguson"  #Default parameters used in the paper
bio=c(Ferguson="",CDC_mean="_CDC")

#Define the beta(m) parameter to be used from September 1 (start of simulation period):
bm_Sim = 0.0

#Define T_inf to be used from September 1 (start of simulation period):
TINF1=0

######### End of parameters setting

#Time variables:
TimeHoriz = 306+364  #(Starting time variable: January 1 2020. Default ending period: Nov 1 2021)
time = c(1:TimeHoriz)

###
source("Code/SEIR_HC_SEC_AGE.R")
###

#Load Protezione Civile Data:
if (Region == 1){
  real_data <- read.csv("Data/LOMBARDIA.csv")
} else if (Region == 2) {
  real_data <- read.csv("Data/VENETO.csv")
}

###Variables preparation###

#The first observation from Protezione Civile is dated 24 february, while in our
#model we consider 8 march as the 68th observation. For this reason we have to
#rescale the observed data to match the correct date:

Date = as.Date(ICU_Lomb_Ven$date)

TotEffFAT_obs        = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
Delta_fatalities_obs = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
ICU_obs              = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
Hosp_obs             = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
delta_Hosp_obs       = matrix(data = NA, nrow = TimeHoriz, ncol = 1)

Delta_fatalities     = zeros(length(real_data$data), 1)
Delta_fatalities[2:(length(real_data$data))] = diff(real_data$deceduti)

for (t in 55:(54 + length(real_data$data))) {
  TotEffFAT_obs[t]        = real_data$deceduti[(t-54)]
  Delta_fatalities_obs[t] = Delta_fatalities[(t-54)]
  ICU_obs[t]              = real_data$terapia_intensiva[(t-54)]
  Hosp_obs[t]             = real_data$totale_ospedalizzati[(t-54)]
}

delta_Hosp_obs[2:length(delta_Hosp_obs)] = diff(Hosp_obs)

#Graphs setting
X_lim = Oct23 #to restrict the graph to the first x values 
maggio4 = Date[125]
marzo8  = Date[68]
ottobre23 = Date[Oct23]
settembre14 = Date[Sept14]
dt_shapes = seq(from = 6, to = X_lim, by = 7) 

region=c("_Lombardia", "_Veneto")
Title=c("Lombardia", "Veneto")
###############################
# GRAPH WITH TOTAL FATALITIES #
###############################

override.shape <- c( 17,2)
colors <- c("Total Fatalities simulated" = "blue", "Total Fatalities observed"="black")

ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = TotFAT[1:X_lim], color = "Total Fatalities simulated"), size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = TotFAT[dt_shapes], color = "Total Fatalities simulated"), size = 2, shape=2) +
  geom_line(aes(x = Date[1:X_lim],y = TotEffFAT_obs[1:X_lim],color="Total Fatalities observed"), size = 0.5, linetype = "solid") +
  geom_point(aes(x = Date[1:X_lim],y = TotEffFAT_obs[1:X_lim],color="Total Fatalities observed"), size = 1, shape=17) +    geom_vline(xintercept=marzo8)+    geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=ottobre23)+
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks", minor_breaks = "2 weeks", limits = c(min(Date), max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,30000,2000), limits = c(0,20000))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.02, .95), legend.justification = c("left", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {  
  ggsave(paste("graphs/A_CALIBRATION/FERGUSON/TOTAL_DEATHS",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {  
  ggsave(paste("graphs/A_CALIBRATION/CDC/TOTAL_DEATHS",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

###############################
# GRAPH WITH DAILY FATALITIES #
###############################

override.shape <- c(17,2)
colors <- c( "Daily Fatalities simulated" = "blue", "Daily Fatalities observed"="black")

ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = TotDeltaFAT[1:X_lim], color = "Daily Fatalities simulated"), size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = TotDeltaFAT[dt_shapes], color = "Daily Fatalities simulated"), size = 2, shape=2) +
  geom_line(aes(x = Date[1:X_lim],y = Delta_fatalities_obs[1:X_lim],color="Daily Fatalities observed"), size = 0.5, linetype = "solid") +
  geom_point(aes(x = Date[1:X_lim],y = Delta_fatalities_obs[1:X_lim],color="Daily Fatalities observed"), size = 1, shape=17) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=settembre14 )+
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=ottobre23)+ 
  scale_x_date(date_labels = "%d %b",  date_breaks = "2 weeks", minor_breaks = "2 weeks",limits = c(min(Date), max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,1000,100), limits = c(0,550))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.02, .95), legend.justification = c("left", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {  
  ggsave(paste("graphs/A_CALIBRATION/FERGUSON/DAILY_DEATHS",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {   
  ggsave(paste("graphs/A_CALIBRATION/CDC/DAILY_DEATHS",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

######################################################
# GRAPH WITH OBSERVED AND SIMULATED HOSPITALIZATIONS #
######################################################

override.shape <- c(17,2)
colors <- c("Hospitalized simulated" = "blue", "Hospitalized observed"="black")

ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = TotHosp[1:X_lim], color = "Hospitalized simulated"), size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = TotHosp[dt_shapes], color = "Hospitalized simulated"), size = 2, shape=2) +
  geom_line(aes(x = Date[1:X_lim],y = Hosp_obs[1:X_lim],color="Hospitalized observed"), size = 0.5, linetype = "solid") +
  geom_point(aes(x = Date[1:X_lim],y = Hosp_obs[1:X_lim],color="Hospitalized observed"), size = 1, shape=17) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=settembre14 )+
  geom_vline(xintercept=ottobre23)+ 
  scale_x_date(date_labels = "%d %b",  date_breaks = "2 weeks", minor_breaks = "2 weeks",limits = c(min(Date), max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,30000,2000), limits = c(0,17000))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .95),  legend.justification = c("right", "top"),
        legend.box.just = "left",   legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
   ggsave(paste("graphs/A_CALIBRATION/FERGUSON/HOSP",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
   ggsave(paste("graphs/A_CALIBRATION/CDC/HOSP",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}


  
###################################
# GRAPH WITH DEMAND AND SUPPLY IC #
###################################

override.shape <- c(15,2,17)
colors <- c("Demand IC" = "blue", "Supply IC"="red", "Used IC observed" = "black")

ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = ICC[1:X_lim], color = "Supply IC"), size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = ICC[dt_shapes], color = "Supply IC"), size = 2, shape=2) +
  geom_line(aes(x = Date[1:X_lim],y = Dem_ICU[1:X_lim],color="Demand IC"), size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = Dem_ICU[dt_shapes],color="Demand IC"), size = 2, shape=15) +
  geom_line(aes(x = Date[1:X_lim],y = ICU_obs[1:X_lim],color="Used IC observed"), size = 0.5, linetype = "solid") +
  geom_point(aes(x = Date[1:X_lim],y = ICU_obs[1:X_lim],color="Used IC observed"), size = 1, shape=17) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=settembre14 )+
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=ottobre23)+ 
  scale_x_date(date_labels = "%d %b",  date_breaks = "2 weeks", minor_breaks = "2 weeks",limits = c(min(Date), max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,2000,250), limits=c(0,2000))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.05, .95), legend.justification = c("left", "top"),
        legend.box.just = "left",legend.margin = margin(1.5, 1.5, 1.5, 1.5))
  
if (Bio_Parm=="Ferguson") {
  ggsave(paste("graphs/A_CALIBRATION/FERGUSON/IC",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
  ggsave(paste("graphs/A_CALIBRATION/CDC/IC",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}  
    
#################
# GRAPH WITH Rt #
#################

override.shape <- 15
dt_shapes = seq(from = 6, to = X_lim, by = 7)
  
ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = R_t[1:X_lim]), color= "blue", size = 1) +
  geom_point(aes(x = Date[dt_shapes],y = R_t[dt_shapes]), color= "blue", size = 2, shape=2) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks", minor_breaks = "2 weeks", limits = c(min(Date), max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,3,0.25), limits=c(0,3))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.05, .95), legend.justification = c("left", "top"),
        legend.box.just = "left",legend.margin = margin(1.5, 1.5, 1.5, 1.5))

if (Bio_Parm=="Ferguson") {
  ggsave(paste("graphs/A_CALIBRATION/FERGUSON/Rt",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
  ggsave(paste("graphs/A_CALIBRATION/CDC/Rt",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} 
   
 
#CALIBRATED AND OBSERVED STATISTICS:######

#Calibrated total fatalities on March 7:
print(TotFAT[67])
#Observed total fatalities on March 7:
print(TotEffFAT_obs[67])

#Calibrated total fatalities on April 4:
print(TotFAT[95])
#Observed total fatalities on April 4:
print(TotEffFAT_obs[95])

#Calibrated total hospitalization on March 7  and April 4:
print(TotHosp[67])
print(Hosp_obs[67])

#Observed total hospitalization on March 7:
print(TotHosp[95])
print(Hosp_obs[95])

#END