
###############
# PLOT:PARETO #
###############

rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
Sys.setlocale("LC_TIME", "English") 

#Load the required packages
listofpackages = c("ggplot2", "matlab","readxl","dplyr", "ggrepel", "latex2exp","rJava","xlsx")

for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

###INITIAL PARAMENTERS TO BE SET HERE###

#Uncomment the region of interest:
#Region=1   #: LOMBARDIA
#Region=2   #: VENETO
region=c("_Lombardia", "_Veneto")
Policy = 0 #Default policy for calibration: 

#Uncomment the biological parameters to be used. Possible values:
#Bio_Parm = "CDC_mean"
#Bio_Parm="Ferguson"  #Default parameters used in the paper
bio=c(Ferguson="",CDC_mean="_CDC")

#Define the beta(m) parameter to be used from September 1 (start of simulation period):
#bm_Sim = 0.7
#bm_Sim = 0.9

#Define T_inf to be used from September 1 (start of simulation period):
TINF1=0

###End of parameters setting

#Time variables:
TimeHoriz = 306+364  #(Starting time variable: January 1 2020. Default ending period: Semptember 1 2021)
time = c(1:TimeHoriz)

#Load the data to be used:
if (Region == 1){
  dati = as.data.frame(read_excel(paste("Data/DATI_LOM_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[1],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE))
}else if (Region == 2) {
  dati = as.data.frame(read_excel(paste("Data/DATI_VEN_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[2],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE))
}

#Graphs setting
region=c("_Lombardia", "_Veneto")
Title=c("Lombardia", "Veneto")

##########
# PARETO #
##########

override.shape <-c(17,18, 20, 19,15,16) 
colors <- c("LOCK" = "darkgoldenrod4", "SEC" = "red", "AGE" = "blue","AGE_SEC" = "chartreuse4", "ALL" = "hotpink" , "AGE_SEC variations"="chartreuse4")

ggplot(dati) +
  geom_point(aes(y= TotalDeadYr, x=GDPLoss, color="AGE_SEC variations"), shape=20,size=3)+
  geom_text_repel(aes(y= TotalDeadYr, x=GDPLoss,label=Name),hjust=1, vjust=1.5)+
  geom_text_repel(aes(y= TotalDeadYr, x=GDPLoss,label=Name2),hjust=0.5, vjust=-1,direction = "y", force=55)+
    
  geom_point(aes(y= TotalDeadYr[1],x=GDPLoss[1], color="LOCK"), shape=15, size=3.5)+
  geom_point(aes(y= TotalDeadYr[2],x=GDPLoss[2], color="SEC"), shape=16,  size=3.5)+
  geom_point(aes(y= TotalDeadYr[3],x=GDPLoss[3], color="AGE"), shape=17, size=3)+
  geom_point(aes(y= TotalDeadYr[4],x=GDPLoss[4],color="AGE_SEC"), shape=18,size=3.5)+
  geom_point(aes(y= TotalDeadYr[5],x=GDPLoss[5], color="ALL"), shape=19,size=3.5)+
  scale_x_continuous(breaks=seq(0,0.5,0.05), limits =c(0,0.26))+
  theme_bw()+
  theme(panel.grid.minor = element_line(size=0.5)) +
  theme( 
  plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
      axis.title.x=element_text( margin=margin(t=5)),
      axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "GDP Loss", y = "Total Fatalities", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .95), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
    ggsave(paste("graphs/C_PARETO/FERGUSON/Pareto4MayEFF_",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
    ggsave(paste("graphs/C_PARETO/CDC/Pareto4MayEFF_",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

#################
# HERD IMMUNITY #
#################
ggplot(dati) +
  geom_point(aes(x=TotalDead,y= HerdImm , color="AGE_SEC variations"), shape=20,size=3)+
  geom_text(aes (x=TotalDead,y= HerdImm,label=Name),hjust=2, vjust=+.4)+
  geom_text_repel(aes (x=TotalDead,y= HerdImm,label=Name2),hjust=-.5, vjust=0.4)+
    
  geom_point(aes(x=TotalDead[1],y= HerdImm[1], color="LOCK"), shape=15, size=3.5)+
  geom_point(aes(x=TotalDead[2],y= HerdImm[2], color="SEC"), shape=16,  size=3.5)+
  geom_point(aes(x=TotalDead[3],y= HerdImm[3], color="AGE"), shape=17, size=3)+
  geom_point(aes(x=TotalDead[4],y= HerdImm[4], color="AGE_SEC"), shape=18,size=3.5)+
  geom_point(aes(x=TotalDead[5],y= HerdImm[5] , color="ALL"), shape=19,size=3.5)+
    
  #scale_x_continuous(breaks=seq(0,60000,5000), limits = c(1000, 58000))+
  #scale_y_continuous(breaks=seq(0,0.2,0.025), limits =c(0.002,0.18))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = Title[Region], x = "Total Fatalities", y = "Herd Immunity", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .7), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
    ggsave(paste("graphs/C_PARETO/FERGUSON/herd_fat_",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
    ggsave(paste("graphs/C_PARETO/CDC/herd_fat_",region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

#####################################################
# PARETO WITH BOTH LOMBARDIA AND VENETO: COMPARISON #
#####################################################

datiLom = as.data.frame(read_excel(paste("Data/DATI_LOM_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[1],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE))
datiVen = as.data.frame(read_excel(paste("Data/DATI_VEN_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[2],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE))

override.shape <-c(16,16) 
linetype <- c("Lombardia" = "dashed", "Veneto" = "solid")

p<-ggplot() +
  geom_line(aes(y= datiLom$TotalDeadYr[-c(2,3,4)]/10, x=datiLom$GDPLoss[-c(2,3,4)],linetype="Lombardia"), color="red")+
  geom_line(aes(y= datiVen$TotalDeadYr[-c(2,3,4)]/4.9, x=datiVen$GDPLoss[-c(2,3,4)],linetype="Veneto"), color="blue")+
  geom_text_repel(aes(y= datiVen$TotalDeadYr/4.9, x=datiVen$GDPLoss,label=datiVen$Name2), hjust=.5, vjust=1.5, color="blue")+
  geom_text_repel(aes(y= datiLom$TotalDeadYr/10, x=datiLom$GDPLoss,label=datiLom$Name2), color="red", hjust=0, vjust=-1.5,direction = "x")+
  
  geom_point(aes(y= datiLom$TotalDeadYr[1]/10,x=datiLom$GDPLoss[1]), shape=15, size=3.5, color="red")+
  geom_point(aes(y= datiLom$TotalDeadYr[2]/10,x=datiLom$GDPLoss[2]),shape=16,  size=3.5, color="red")+
  geom_point(aes(y= datiLom$TotalDeadYr[3]/10,x=datiLom$GDPLoss[3]),shape=17, size=3, color="red")+
  geom_point(aes(y= datiLom$TotalDeadYr[4]/10,x=datiLom$GDPLoss[4]),shape=18,size=3.5, color="red")+
  geom_point(aes(y= datiLom$TotalDeadYr[5]/10,x=datiLom$GDPLoss[5]),shape=19,size=3.5, color="red")+
  
  geom_point(aes(y= datiVen$TotalDeadYr[1]/4.9,x=datiVen$GDPLoss[1]), color="blue",shape=15, size=3.5)+
  geom_point(aes(y= datiVen$TotalDeadYr[2]/4.9,x=datiVen$GDPLoss[2]), color="blue",shape=16,  size=3.5)+
  geom_point(aes(y= datiVen$TotalDeadYr[3]/4.9,x=datiVen$GDPLoss[3]), color="blue",shape=17, size=3)+
  geom_point(aes(y= datiVen$TotalDeadYr[4]/4.9,x=datiVen$GDPLoss[4]), color="blue",shape=18,size=3.5)+
  geom_point(aes(y= datiVen$TotalDeadYr[5]/4.9,x=datiVen$GDPLoss[5]), color="blue",shape=19,size=3.5)+
  
  scale_x_continuous(breaks=seq(0,0.5,0.05), limits =c(0,0.27))+
  theme_bw()+
  theme(panel.grid.minor = element_line(size=0.5)) +
  theme(#  ,angle = 45
    plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
    axis.title.x=element_text( margin=margin(t=5)),
    axis.title.y=element_text( margin=margin(r=5)))+
  labs(title = TeX(paste("\\textbf{With behavioural response;}","\\textbf{$\\beta(m)=$}", bm_Sim)), x = "GDP Loss", y = "Fatalities per million", linetype = "Legend") +
  guides(linetype = guide_legend(override.aes = list(color= c("red", "blue"))))+
  scale_linetype_manual(values = linetype)+
  theme(legend.position = c(0.95, .95), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if(bm_Sim==0.9){p+scale_y_continuous(breaks=seq(0,50000,5000),limits =c(0,16000))
}else if(bm_Sim==0.7){p+scale_y_continuous(breaks=seq(0,50000,1000),limits =c(0,7500))}

if (Bio_Parm=="Ferguson") {
ggsave(paste("graphs/C_PARETO/FERGUSON/Pareto_Confronto_bm_",bm_Sim,"_Tinf1_",TINF1,bio[Bio_Parm],".png",sep = "")
         , width = 8, height = 5)
print(paste("graphs/C_PARETO/FERGUSON/Pareto_Confronto_bm_",bm_Sim,"_Tinf1_",TINF1,bio[Bio_Parm],".png",sep = ""))
} else if (Bio_Parm=="CDC_mean") {
ggsave(paste("graphs/C_PARETO/CDC/Pareto_Confronto_bm_",bm_Sim,"_Tinf1_",TINF1,bio[Bio_Parm],".png",sep = "")
         , width = 8, height = 5)
print (paste("graphs/C_PARETO/CDC/Pareto_Confronto_bm_",bm_Sim,"_Tinf1_",TINF1,bio[Bio_Parm],".png",sep = ""))
}

#END

