
#############################
# PLOT: INITIAL COMPARISONS #
#############################

rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
Sys.setlocale("LC_TIME", "English")

listofpackages = c("ggplot2", "matlab","readxl","dplyr","ggpubr","pracma")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

#Define time variables:
TimeHoriz = 365
ICU_Lomb_Ven = read_excel("Data/ICU_Lomb_Ven.xlsx")
Date = as.Date(ICU_Lomb_Ven$date)

#Load the data:
real_data_lom <- read.csv("Data/LOMBARDIA.csv")
real_data_ven <- read.csv("Data/VENETO.csv")

#Correct the second Total swabs observation for Lombardia (the variable takes value 1463, 3700, 3208, 3320...)
real_data_lom$tamponi[2] = (real_data_lom$tamponi[1]+real_data_lom$tamponi[3])/2

###Variables preparation###

#The first observation from Protezione Civile is dated 24 february, while in our
#model we consider 8 march as the 68th observation. For this reason we have to
#rescale the observed data to match the correct date:

#For each variable the first column stores Lombardy data, the second Veneto ones

Hosp_obs           = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Active_obs         = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Total_cases_obs    = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Nuovi_positivi_obs = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Total_swabs_obs    = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Isolated_obs       = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Total_Deaths_obs   = matrix(data = NA, nrow = TimeHoriz, ncol = 2)

Delta_Hosp_obs  = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Daily_swabs_obs = matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Daily_Deaths_obs= matrix(data = NA, nrow = TimeHoriz, ncol = 2)
Daily_swabs_obs_per_habitant_ma= matrix(data = NA, nrow = TimeHoriz, ncol = 2)
for (t in 55:(54 + length(real_data_lom$data))) {
  
  Hosp_obs[t,1]           = real_data_lom$totale_ospedalizzati[(t-54)]
  Hosp_obs[t,2]           = real_data_ven$totale_ospedalizzati[(t-54)]
  
  Active_obs[t,1]         = real_data_lom$totale_positivi[(t-54)]
  Active_obs[t,2]         = real_data_ven$totale_positivi[(t-54)]
  
  Total_cases_obs[t,1]    = real_data_lom$totale_casi[(t-54)]
  Total_cases_obs[t,2]    = real_data_ven$totale_casi[(t-54)]
  
  Nuovi_positivi_obs[t,1] = real_data_lom$nuovi_positivi[(t-54)]
  Nuovi_positivi_obs[t,2] = real_data_ven$nuovi_positivi[(t-54)]
  
  Total_swabs_obs[t,1]    = real_data_lom$tamponi[(t-54)]
  Total_swabs_obs[t,2]    = real_data_ven$tamponi[(t-54)]
  
  Isolated_obs[t,1]       = real_data_lom$isolamento_domiciliare[(t-54)]
  Isolated_obs[t,2]       = real_data_ven$isolamento_domiciliare[(t-54)]
  
  Total_Deaths_obs[t,1]       = real_data_lom$deceduti[(t-54)]
  Total_Deaths_obs[t,2]       = real_data_ven$deceduti[(t-54)]
}

Daily_Deaths_obs[2:TimeHoriz,] = diff(Total_Deaths_obs) 

#Delta_Hosp_obs[2:TimeHoriz,] = diff(Hosp_obs)
Hosp_over_Active_obs = Hosp_obs / Active_obs
Isolated_over_Active_obs = Isolated_obs / Active_obs

Daily_swabs_obs[2:TimeHoriz,] = diff(Total_swabs_obs) 

Daily_swabs_obs_per_habitant = Daily_swabs_obs
Daily_swabs_obs_per_habitant[,1] = Daily_swabs_obs_per_habitant[,1]/10000000
Daily_swabs_obs_per_habitant[,2] = Daily_swabs_obs_per_habitant[,2]/4900000

Total_swabs_obs_per_habitant = Total_swabs_obs
Total_swabs_obs_per_habitant[,1] = Total_swabs_obs_per_habitant[,1]/10000000
Total_swabs_obs_per_habitant[,2] = Total_swabs_obs_per_habitant[,2]/4900000


Daily_swabs_obs_per_habitant_ma[,1]= movavg(Daily_swabs_obs_per_habitant[,1],7)
Daily_swabs_obs_per_habitant_ma[,2]= movavg(Daily_swabs_obs_per_habitant[,2],7)

#All the ratios are taken as Lombardy over Veneto
Ratio_Total_swabs_obs = Total_swabs_obs[,1]/Total_swabs_obs[,2] 
Ratio_Total_swabs_obs_per_habitant = Total_swabs_obs_per_habitant[,1]/Total_swabs_obs_per_habitant[,2] 
Ratio_Daily_swabs_obs = Daily_swabs_obs[,1]/Daily_swabs_obs[,2]
Ratio_Daily_swabs_obs_per_habitant = Daily_swabs_obs_per_habitant[,1]/Daily_swabs_obs_per_habitant[,2]

#Graphs setting
X_lim = 297 #Oct23 #to restrict the graph to the first x values 
maggio4 = Date[125]
marzo8  = Date[68]
settembre14 = Date[258]
override.shape <- c(15, 16)
dt_shapes = seq(from = 6, to = X_lim, by = 7) 
colors <- c("Lombardia" = "blue", "Veneto"="red")
theme_small<- theme(axis.text.x = element_text(size = rel(.9)),
                    axis.title.y= element_text(size = rel(.9)),
                    axis.text.y = element_text(size = rel(.9)),
                    legend.text = element_text(size = rel(.9)),
                    legend.title = element_text(size =rel(.8)),
                    plot.title = element_text(size=rel(.8)),
                    plot.margin = unit(c(0.1,0.2,0,0.2), "lines"))

################
# Daily deaths #
################

p1<-ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = Daily_Deaths_obs[1:X_lim,1],color="Lombardia"), size = 0.75, linetype = "solid") +
  geom_point(aes(x = Date[dt_shapes],y = Daily_Deaths_obs[dt_shapes,1],color="Lombardia"), size = 2, shape=15) +
  geom_line(aes(x = Date[1:X_lim],y = Daily_Deaths_obs[1:X_lim,2],color="Veneto"), size = 0.75, linetype = "solid") +
  geom_point(aes(x = Date[dt_shapes],y = Daily_Deaths_obs[dt_shapes,2],color="Veneto"), size = 2, shape=16) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks",limits = c(Date[49], max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,600,100))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = "Daily deaths", x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+theme_small

###################################
# HOSPITALAZIED OVER ACTIVE CASES #
###################################

p2<-ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = Hosp_over_Active_obs[1:X_lim,1], color = "Lombardia"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Hosp_over_Active_obs[dt_shapes,1], color = "Lombardia"), size = 2, shape=15) +
  geom_line(aes(x = Date[1:X_lim],y = Hosp_over_Active_obs[1:X_lim,2],color="Veneto"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Hosp_over_Active_obs[dt_shapes,2],color="Veneto"), size = 2, shape=16) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=maggio4)+
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks",limits = c(Date[49], max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,1,0.2), limits = c(0,1))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = "Hospitalized over active cases", x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+theme_small

##############################
# ISOLATED OVER ACTIVE CASES #
##############################

p3<- ggplot() +
  geom_line(aes(x = Date[1:X_lim],y = Isolated_over_Active_obs[1:X_lim,1], color = "Lombardia"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Isolated_over_Active_obs[dt_shapes,1], color = "Lombardia"), size = 2, shape=15) +
  geom_line(aes(x = Date[1:X_lim],y = Isolated_over_Active_obs[1:X_lim,2],color="Veneto"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Isolated_over_Active_obs[dt_shapes,2],color="Veneto"), size = 2, shape=16) +
  geom_vline(xintercept=marzo8)+ 
  geom_vline(xintercept=maggio4)+ 
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks",limits = c(Date[49], max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous(breaks=seq(0,1,0.2), limits = c(0,1))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = "Domestic quarantine over active cases", x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme_small

############################
# DAILY SWABS PER HABITANT #
############################  

p4<-ggplot() +
  geom_line(aes(x = Date[1:X_lim],y =Daily_swabs_obs_per_habitant_ma[1:X_lim,1], color = "Lombardia"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Daily_swabs_obs_per_habitant_ma[dt_shapes,1], color = "Lombardia"), size = 2, shape=15) +
  geom_line(aes(x = Date[1:X_lim],y = Daily_swabs_obs_per_habitant_ma[1:X_lim,2],color="Veneto"), size = 0.75) +
  geom_point(aes(x = Date[dt_shapes],y = Daily_swabs_obs_per_habitant_ma[dt_shapes,2],color="Veneto"), size = 2, shape=16) +
  geom_vline(xintercept=marzo8)+
  geom_vline(xintercept=maggio4)+
  geom_vline(xintercept=settembre14 )+
  scale_x_date(date_labels = "%d %b", date_breaks = "2 weeks",limits = c(Date[49], max= Date[X_lim]), expand = c(0,0))+
  scale_y_continuous()+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1, angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = "Daily swabs per habitant", x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+theme_small

ggarrange(p1,p2,p3,p4, ncol = 2,  nrow = 2, common.legend = T, legend="bottom")

ggsave("graphs/D_PRELIMINARIES/preliminary_comparison.pdf", width = 8, height = 5)

