
####################
# PLOT: R MATRICES #
####################

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
rm(list=ls())

# load packages
listofpackages = c("ellipse","reshape2","ggplot2","dygraphs", "dplyr","scales")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}


matrices=c("RZerNormal", "RZerLockEq")
region=c("Lombardia", "Veneto")

for (reg in region){
  for (mat in matrices){
    for (bio in c("","_CDC")) {  #
    #import   
    R=read.csv2(paste("Data/",mat,"_",reg,bio,".csv",sep = ""), header = T, stringsAsFactors = T, sep = ";")[,-1]
    rownames(R) <- c("0-9","10-19","20-29_A_LR","30-39_A_LR","40-49_A_LR","50-59_A_LR","60-69_A_LR","20-29_A_HR","30-39_A_HR","40-49_A_HR","50-59_A_HR","60-69_A_HR","20-29_IN","30-39_IN","40-49_IN","50-59_IN","60-69_IN","70-79","over 80")
    colnames(R) <- c("0-9","10-19","20-29_A_LR","30-39_A_LR","40-49_A_LR","50-59_A_LR","60-69_A_LR","20-29_A_HR","30-39_A_HR","40-49_A_HR","50-59_A_HR","60-69_A_HR","20-29_IN","30-39_IN","40-49_IN","50-59_IN","60-69_IN","70-79","over 80")
    
    R=as.matrix(R, rownames=TRUE, byrow = TRUE)
    R=R[,ncol(R):1]
    R=melt(R)
    ggplot(R, aes(Var1, Var2)) + # x and y axes => Var1 and Var2
      geom_tile(aes(fill = value), size=2) + # background colours are mapped according to the value column
      geom_text(aes(label = round(value, 2)), size=3) + # write the values
      scale_fill_gradient2(low = muted("midnightblue"), 
                           mid = "white", 
                           high = muted("darkred"), 
                           midpoint = 1) +# determine the colour
      theme(panel.grid.major.x=element_blank(), #no gridlines
            panel.grid.minor.x=element_blank(), 
            panel.grid.major.y=element_blank(), 
            panel.grid.minor.y=element_blank(),
            panel.background=element_rect(fill="white"), # background=white
            axis.text.x = element_text(angle=90, hjust = 1,vjust=1,size = 8,face = "bold"),
            plot.title = element_text(size=9,face="bold"),
            axis.text.y = element_text(size = 8,face = "bold")) + 
      labs(title = reg, x = "", y = "") +
      theme(legend.title=element_text(face="bold", size=10)) + 
      scale_x_discrete(name="") +
      scale_y_discrete(name="") +
      labs(fill="R0")
    ggsave(paste("graphs/M_MATRICES/NORMAL_AND_LOCK/",mat,"_",reg,bio,".png",sep = ""), width = 8, height = 5)
  }}}

mat="RZerSeparAct_eq_bm_"
region=c("Lombardia", "Veneto")
policy=c(1, 2, 3, 4, 5)

policy_name = c("LOCK", "SEC", "AGE", "AGE_SEC", "ALL")

#Define T_inf that has been used from September 1 (start of simulation period):
TINF1=0
Tinf1=0
for (reg in region){
    for (pol in policy){
      for (bm_Sim in c(0.7,0.9)) {
          for (bio in c("","_CDC")) { 
      #import   
      R=read.csv2(paste("Data/",mat,bm_Sim,"_Tinf1_",Tinf1,"_",reg,"_",pol,bio,".csv",sep = ""), header = T, stringsAsFactors = T, sep = ";")[,-1]
      rownames(R) <- c("0-9","10-19","20-29_A_LR","30-39_A_LR","40-49_A_LR","50-59_A_LR","60-69_A_LR","20-29_A_HR","30-39_A_HR","40-49_A_HR","50-59_A_HR","60-69_A_HR","20-29_IN","30-39_IN","40-49_IN","50-59_IN","60-69_IN","70-79","over 80")
      colnames(R) <- c("0-9","10-19","20-29_A_LR","30-39_A_LR","40-49_A_LR","50-59_A_LR","60-69_A_LR","20-29_A_HR","30-39_A_HR","40-49_A_HR","50-59_A_HR","60-69_A_HR","20-29_IN","30-39_IN","40-49_IN","50-59_IN","60-69_IN","70-79","over 80")
      
      R=as.matrix(R, rownames=TRUE, byrow = TRUE)
      R=R[,ncol(R):1]
      R=melt(R)
      ggplot(R, aes(Var1, Var2)) + # x and y axes => Var1 and Var2
        geom_tile(aes(fill = value), size=2) + # background colours are mapped according to the value column
        geom_text(aes(label = round(value, 2)), size=3) + # write the values
        scale_fill_gradient2(low = muted("midnightblue"), 
                             mid = "white", 
                             high = muted("darkred"), 
                             midpoint = 1) +# determine the colour
        theme(panel.grid.major.x=element_blank(), #no gridlines
              panel.grid.minor.x=element_blank(), 
              panel.grid.major.y=element_blank(), 
              panel.grid.minor.y=element_blank(),
              panel.background=element_rect(fill="white"), # background=white
              axis.text.x = element_text(angle=90, hjust = 1,vjust=1,size = 8,face = "bold"),
              plot.title = element_text(size=9,face="bold"),
              axis.text.y = element_text(size = 8,face = "bold")) + 
        labs(title = reg, x = "", y = "") +
        theme(legend.title=element_text(face="bold", size=10)) + 
        scale_x_discrete(name="") +
        scale_y_discrete(name="") +
        labs(fill="R0")
      ggsave(paste("graphs/M_MATRICES/POLICIES/",mat,bm_Sim,"_Tinf1_",Tinf1,"_",reg,"_",pol,bio,".png",sep = ""), width = 8, height = 5)
  }}}}

#END