
#######################################################################
# FILE: MATCHING THE SAME EFFICIENT POLICIES FOR LOMBARDIA AND VENETO #
#######################################################################

rm(list = ls())
wd= dirname(rstudioapi::getActiveDocumentContext()$path)
setwd(substr(wd,1,nchar(wd)-5))

#Load the required packages
listofpackages = c("readxl","rJava","xlsx","dplyr")
for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

###INITIAL PARAMENTERS TO BE SET HERE###

#Uncomment the region of interest:
#Region=1   #: LOMBARDIA
#Region=2   #: VENETO
region=c("_Lombardia", "_Veneto")

Policy=1024 #: Policy used for Pareto

#Uncomment the biological parameters to be used. Possible values:
#Bio_Parm = "CDC_mean"
#Bio_Parm="Ferguson"  #Default parameters used in the paper
bio=c(Ferguson="",CDC_mean="_CDC")

#Define the beta(m) parameter to be used from September 1 (start of simulation period):
#bm_Sim = 0.7 
#bm_Sim = 0.9 

#Define T_inf to be used from September 1 (start of simulation period):
TINF1=0

######### End of parameters setting
datiLom = as.data.frame(read_excel(paste("Data/DATI_LOM_bm_",bm_Sim,"_Tinf1_",TINF1,region[1],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE)) 
datiVen = as.data.frame(read_excel(paste("Data/DATI_VEN_bm_",bm_Sim,"_Tinf1_",TINF1,region[2],bio[Bio_Parm],".xlsx",sep = ""), col_names = TRUE))

datiVen=datiVen%>%
  mutate(NAME = case_when(alpha1==1   &alpha2==1   &alpha3==1   &alpha4==1   &alpha5==1   &
                                alpha6==1   &alpha7==1   &alpha8==1   &alpha9==1   &alpha10==1   ~ 'ALL',

                                alpha1==1   &alpha2==1   &alpha3==1   &alpha4==1   &alpha5==1  &
                                alpha6==0.6  &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6 ~ 'SEC',

                                alpha1==1   &alpha2==1   &alpha3==1   &alpha4==0.6 &alpha5==0.6  &
                                alpha6==1   &alpha7==1   &alpha8==1   &alpha9==0.6 &alpha10==0.6  ~ 'AGE',

                                alpha1==1   &alpha2==1   &alpha3==1   &alpha4==0.6 &alpha5==0.6  &
                                alpha6==1   &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6  ~ 'AGE_SEC',

                                alpha1==0.6 &alpha2==0.6 &alpha3==0.6 &alpha4==0.6 &alpha5==0.6  &
                                alpha6==0.6 &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6  ~ 'LOCK'))

datiVen=datiVen%>%
  mutate(NAME3 = case_when( NAME=="ALL"~ 'TUTTI',
                            NAME=="SEC"~ 'SET',
                            NAME=="AGE"~ 'ET?',
                            NAME=="AGE_SEC"~ 'ET?_SET',
                            NAME=="LOCK"~ 'LOCKDOWN'))

datiLom=datiLom%>%
  mutate(NAME = case_when(alpha1==1   &alpha2==1   &alpha3==1   &alpha4==1   &alpha5==1   &
                             alpha6==1   &alpha7==1   &alpha8==1   &alpha9==1   &alpha10==1   ~ 'ALL',
                           
                           alpha1==1   &alpha2==1   &alpha3==1   &alpha4==1   &alpha5==1  &
                             alpha6==0.6  &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6 ~ 'SEC',
                           
                           alpha1==1   &alpha2==1   &alpha3==1   &alpha4==0.6 &alpha5==0.6  &
                             alpha6==1   &alpha7==1   &alpha8==1   &alpha9==0.6 &alpha10==0.6  ~ 'AGE',
                           
                           alpha1==1   &alpha2==1   &alpha3==1   &alpha4==0.6 &alpha5==0.6  &
                             alpha6==1   &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6  ~ 'AGE_SEC',
                           
                           alpha1==0.6 &alpha2==0.6 &alpha3==0.6 &alpha4==0.6 &alpha5==0.6  &
                             alpha6==0.6 &alpha7==0.6 &alpha8==0.6 &alpha9==0.6 &alpha10==0.6  ~ 'LOCK'))
 
datiLom=datiLom%>%
  mutate(NAME3 = case_when(NAME=="ALL"~ 'TUTTI',
                           NAME=="SEC"~ 'SET',
                           NAME=="AGE"~ 'ET?',
                           NAME=="AGE_SEC"~ 'ET?_SET',
                           NAME=="LOCK"~ 'LOCKDOWN'))
datiLom[order(datiLom$TotalDead),]
datiVen[order(datiVen$TotalDead),]

POL=subset(datiLom,datiLom$NAME!="")[,c(1,7:17)] #Policies
LOM=datiLom[is.na(datiLom$NAME),][,c(1,7:16)]    #Lombardia activation vectors(AV) without policies
VEN=datiVen[is.na(datiVen$NAME),][,c(1,7:16)]    #Veneto activation vectors(AV) without policies
Keys=names(VEN)[-1]

BOTH=merge(LOM,VEN,by=Keys,all=FALSE)       #AV in common
  colnames(BOTH)[11]<-c("ORD")
  BOTH$ORD <- as.numeric(BOTH$ORD)
  BOTH = BOTH[order(BOTH$ORD),]
  from1 =1
  to1   =dim(BOTH)[1]
  BOTH_N=cbind(BOTH, NAME=seq(from1,to1))[c(Keys,"NAME")]
ONLYLOM=anti_join(LOM, BOTH, by = Keys)     #AV present only in Lombardy
  from2 =to1+1
  to2   =to1+dim(ONLYLOM)[1]
 
if (to2 < from2){
  ONLYVEN=anti_join(VEN, BOTH, by = Keys)     #AV present only in Veneto
  from3 =to2+1
  to3   =to2+dim(ONLYVEN)[1]
  ONLYVEN_N=cbind(ONLYVEN,NAME=seq(from3,to3))[c(Keys,"NAME")]
  match=rbind(BOTH_N,ONLYVEN_N)       #merge all except policies
} else {
  ONLYLOM_N=cbind(ONLYLOM,NAME=seq(from2,to2))[c(Keys,"NAME")]
  ONLYVEN=anti_join(VEN, BOTH, by = Keys)     #AV present only in Veneto
  from3 =to2+1
  to3   =to2+dim(ONLYVEN)[1]
  ONLYVEN_N=cbind(ONLYVEN,NAME=seq(from3,to3))[c(Keys,"NAME")]
  match=rbind(BOTH_N,ONLYLOM_N,ONLYVEN_N)       #merge all except policies
}

datiVen2=merge(datiVen, match, by=Keys,all.x  = TRUE)
colnames(datiVen2)[17:19]<-c("Name2", "Name3","Name")
LOCK=subset(datiVen2, Name2=="LOCK")

SEC=subset(datiVen2, Name2=="SEC")
AGE=subset(datiVen2, Name2=="AGE")
AGE_SEC=subset(datiVen2, Name2=="AGE_SEC")
ALL=subset(datiVen2, Name2=="ALL")
Y=subset(datiVen2, Name!="")
Y=Y[order(Y$Name),]
datiVen3=rbind(LOCK,SEC,AGE,AGE_SEC,ALL,Y)
write.xlsx(datiVen3[-11], paste("Data/DATI_VEN_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[2],bio[Bio_Parm],".xlsx",sep = ""),showNA=FALSE,row.names=FALSE)
print( paste("Data/DATI_VEN_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[2],bio[Bio_Parm],".xlsx",sep = ""))
datiLom2=merge(datiLom, match, by=Keys,all.x = TRUE)
colnames(datiLom2)[17:19]<-c("Name2", "Name3","Name")
datiLom2$Name<-as.numeric(datiLom2$Name)
datiLom2[order(datiLom2$GDPLoss),]
datiLom2[order(datiLom2$Name),]
LOCK=subset(datiLom2, Name2=="LOCK")
SEC=subset(datiLom2, Name2=="SEC")
AGE=subset(datiLom2, Name2=="AGE")
AGE_SEC=subset(datiLom2, Name2=="AGE_SEC")
ALL=subset(datiLom2, Name2=="ALL")
Y=subset(datiLom2, Name!="")
Y=Y[order(Y$Name),]
datiLom3=rbind(LOCK,SEC,AGE,AGE_SEC,ALL,Y)
write.xlsx(datiLom3[-11], paste("Data/DATI_LOM_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[1],bio[Bio_Parm],".xlsx",sep = ""),showNA=FALSE,row.names=FALSE)
print(paste("Data/DATI_LOM_N_bm_",bm_Sim,"_Tinf1_",TINF1,region[1],bio[Bio_Parm],".xlsx",sep = ""))

#END

