
#############################
# PLOT: POLICIES SIMULATION #
#############################

rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
Sys.setlocale("LC_TIME", "English") 

#Load the required packages
listofpackages = c("ggplot2", "matlab","readxl","dplyr", "ggrepel","latex2exp","rJava", "xlsx")

for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

###INITIAL PARAMENTERS TO BE SET HERE###

#Uncomment the biological parameters to be used. Possible values:
#Bio_Parm = "CDC_mean"
#Bio_Parm="Ferguson"  #Default parameters used in the paper
bio=c(Ferguson="",CDC_mean="_CDC")

#Define T_inf to be used from September 1 (start of simulation period):
TINF1=0
######### End of parameters setting

#Time variables:
TimeHoriz = 306+364  #(Starting time variable: January 1 2020. Default ending period: Semptember 1 2021)
time = c(1:TimeHoriz)

for (Region in 1:2) { 
for (bm_Sim in c(0.7,0.9)) {

#Description of the policies implemented:
#Policy=1: LOCK         Prolonged lockdown 
#Policy=2: SEC          Going back to work by risk sectors
#Policy=3: AGE          Going back to work by age
#Policy=4: AGE_SEC      Going back to work by risk sectors and age; adjust as desired
#Policy=5: ALL          Benchmark if we had done nothing and all back to work 

#Creation of matrices that will store data for next graphs
TotDeltaEffFATMat = matrix(data = NA, nrow = TimeHoriz, ncol = 5)  
TotEffFATMat = matrix(data = NA, nrow = 1, ncol = 5)  
TotEffFATMat_Nov1 = matrix(data = NA, nrow = 1, ncol = 5)  
AvgRZeroEQ = matrix(data = NA, nrow = 1, ncol = 5)
AvgRt = matrix(data = NA, nrow = TimeHoriz, ncol = 5)  

###############################################
for(Policy in c(1,2,3,4,5)){
  
source("Code/SEIR_HC_SEC_AGE.R")
  TotDeltaEffFATMat[,Policy] = TotDeltaFAT
  TotEffFATMat[Policy] = TotFAT[TimeHoriz]
  TotEffFATMat_Nov1[Policy]=TotFAT[TimeHoriz]-TotFAT[TimeStartNewPolicy-1]
  AvgRZeroEQ[,Policy]= t(FracPopSec)%*%RZerSeparAct_eq%*%FracPopSec
  AvgRt[,Policy]= R_t
}
#################################################

Date= as.Date(ICU_Lomb_Ven$date)
#Load Protezione Civile Data:
if (Region == 1){
  real_data <- read.csv("Data/LOMBARDIA.csv")
} else if (Region == 2) {
  real_data <- read.csv("Data/VENETO.csv")
}

###Variables preparation###

#The first observation from Protezione Civile is dated 24 february, while in our
#model we consider 8 march as the 68th observation. For this reason we have to
#rescale the observed data to match the correct date:

Date = as.Date(ICU_Lomb_Ven$date)

TotEffFAT_obs        = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
Delta_fatalities_obs = matrix(data = NA, nrow = TimeHoriz, ncol = 1)
Delta_fatalities     = zeros(length(real_data$data), 1)
Delta_fatalities[2:(length(real_data$data))] = diff(real_data$deceduti)

for (t in 55:(54 + length(real_data$data))) {
  TotEffFAT_obs[t]        = real_data$deceduti[(t-54)]
  Delta_fatalities_obs[t] = Delta_fatalities[(t-54)]
}

#Graphs setting
X_lim = TimeHoriz 
dt_shapes = seq(from = Nov1, to = X_lim, by = 7)
maggio4=Date[125]
marzo8=Date[68]
ottobre23 = Date[Oct23]
novembre1 = Date[Nov1]

start=Nov1

region=c("_Lombardia", "_Veneto")
Title=c("Lombardia", "Veneto")

#############################
# GRAPH WITH THE 5 POLICIES #
#############################

override.shape <- c(2,10,0,1,0,17)
colors <- c("LOCK" = "darkgoldenrod4", "SEC" = "red", "AGE" = "darkslategrey","SEC_AGE" = "chartreuse4", "ALL" = "hotpink" , "Daily Fatalities observed"="black")

ggplot() +
  geom_line(aes(x = Date[1:X_lim], y = TotDeltaEffFATMat[1:X_lim,2], color = "SEC"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,2], color = "SEC"), size = 2, shape=1) +
  geom_line(aes(x = Date[1:X_lim], y = TotDeltaEffFATMat[1:X_lim,3], color = "AGE"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,3], color = "AGE"), size = 2, shape=2) +
  geom_line(aes(x = Date[1:X_lim], y = TotDeltaEffFATMat[1:X_lim,4], color = "SEC_AGE"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,4], color = "SEC_AGE"), size = 2, shape=5) +
  geom_line(aes(x = Date[1:X_lim], y = TotDeltaEffFATMat[1:X_lim,5], color = "ALL"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,5], color = "ALL"), size = 2, shape=10) +
  geom_line(aes(x = Date[1:X_lim], y = TotDeltaEffFATMat[1:X_lim,1], color = "LOCK"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,1], color = "LOCK"), size = 2, shape=0) +
  geom_line(aes(x = Date[1:start], y = TotDeltaEffFATMat[1:start,1]), color = "blue", size = 1) +
  geom_line(aes(x = Date[1:Oct23],y = Delta_fatalities_obs[1:Oct23],color="Daily Fatalities observed"), size = 0.5, linetype = "solid") +
  geom_point(aes(x = Date[1:Oct23],y = Delta_fatalities_obs[1:Oct23],color="Daily Fatalities observed"), size = 1, shape=17) +
  geom_vline(xintercept=marzo8)+
  geom_vline(xintercept=maggio4)+
  geom_vline(xintercept=Date[Sept14])+ 
  geom_vline(xintercept=novembre1, color="red")+ 
  scale_x_date(date_labels = "%d %b %y", date_breaks = "1 months", expand = c(0,0),limits=c(Date[1], Date[TimeHoriz]))+
  scale_y_continuous(breaks=seq(0,1600,50), limits=c(0, 550))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title =TeX(paste(Title[Region],"without behavioural response;","$\\beta(m)=$", bm_Sim)), x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .95), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
ggsave(paste("graphs/B_POLICIES/FERGUSON/5_POLICY_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
  ggsave(paste("graphs/B_POLICIES/CDC/5_POLICY_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

###################################################################
# GRAPH WITH THE 5 POLICIES STARTING FROM SEPTEMBER 1 2020 (ZOOM) #
###################################################################

override.shape <- c(2,10,0,1,0)
colors <- c("LOCK" = "darkgoldenrod4", "SEC" = "red", "AGE" = "darkslategrey","SEC_AGE" = "chartreuse4", "ALL" = "hotpink" , "Tot. Observed"="black")

ggplot() +
  geom_line(aes(x = Date[start:X_lim], y = TotDeltaEffFATMat[start:X_lim,2], color = "SEC"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,2], color = "SEC"), size = 2, shape=1) +
  geom_line(aes(x = Date[start:X_lim], y = TotDeltaEffFATMat[start:X_lim,3], color = "AGE"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,3], color = "AGE"), size = 2, shape=2) +
  geom_line(aes(x = Date[start:X_lim], y = TotDeltaEffFATMat[start:X_lim,4], color = "SEC_AGE"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,4], color = "SEC_AGE"), size = 2, shape=5) +
  geom_line(aes(x = Date[start:X_lim], y =TotDeltaEffFATMat[start:X_lim,5], color = "ALL"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,5], color = "ALL"), size = 2, shape=10) +
  geom_line(aes(x = Date[start:X_lim], y = TotDeltaEffFATMat[start:X_lim,1], color = "LOCK"), size = 1) +
  geom_point(aes(x = Date[dt_shapes], y = TotDeltaEffFATMat[dt_shapes,1], color = "LOCK"), size = 2, shape=0) +
  geom_vline(xintercept=marzo8)+
  geom_vline(xintercept=maggio4)+   
  scale_x_date(date_labels = "%d %b %y", date_breaks = "1 months", expand = c(0,0),limits=c(Date[start],Date[TimeHoriz]))+
  scale_y_continuous(breaks=seq(0,300,20), limits=c(0, 245))+
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45),
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = TeX(paste(Title[Region],"without behavioural response;","$\\beta(m)=$", bm_Sim)), x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .95), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
ggsave(paste("graphs/B_POLICIES/FERGUSON/5_POLICY_ZOOM_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
  ggsave(paste("graphs/B_POLICIES/CDC/5_POLICY_ZOOM_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}


###############################################
# GRAPH WITH THE 5 Rt  FROM SEMPTEMBER 1 2020 #
###############################################

AvgRt_sim=AvgRt[Nov1:TimeHoriz-1,]
mean_AvgRt_sim=sum(AvgRt_sim)/dim(AvgRt_sim)[1]
max_AvgRt_sim=matrix(NA,ncol=5,nrow=1)
min_AvgRt_sim=matrix(NA,ncol=5,nrow=1)

for (i in 1:5){
max_AvgRt_sim[i]=max(AvgRt_sim[2:365,i])
min_AvgRt_sim[i]=min(AvgRt_sim[2:365,i])
}

X_lim = TimeHoriz
override.shape <- c(2,10,0,1,0)
dt_shapes = seq(from = 125, to = X_lim, by = 7)
colors <- c("LOCK" = "darkgoldenrod4", "SEC" = "red", "AGE" = "darkslategrey","SEC_AGE" = "chartreuse4", "ALL" = "hotpink" , "Tot. Observed"="black")
maggio4=Date[125]
marzo8=Date[68]
start=Nov1

ggplot() +
  geom_line(aes(x = Date[start:X_lim], y = AvgRt_sim[,2], color = "SEC"), size = 1) +
  #geom_point(aes(x = Date[dt_shapes], y = AvgRt_sim[dt_shapes,2], color = "SEC"), size = 2, shape=1) +
  geom_line(aes(x = Date[start:X_lim], y = AvgRt_sim[,3], color = "AGE"), size = 1) +
  #geom_point(aes(x = Date[dt_shapes], y = AvgRt_sim[dt_shapes,3], color = "AGE"), size = 2, shape=2) +
  geom_line(aes(x = Date[start:X_lim], y =AvgRt_sim[,4], color = "SEC_AGE"), size = 1) +
  #geom_point(aes(x = Date[dt_shapes], y =AvgRt_sim[dt_shapes,4], color = "SEC_AGE"), size = 2, shape=5) +
  geom_line(aes(x = Date[start:X_lim], y =AvgRt_sim[,5], color = "ALL"), size = 1) +
  #geom_point(aes(x = Date[dt_shapes], y =AvgRt_sim[dt_shapes,5], color = "ALL"), size = 2, shape=10) +
  geom_line(aes(x = Date[start:X_lim], y =AvgRt_sim[,1], color = "LOCK"), size = 1) +
  #geom_point(aes(x = Date[dt_shapes], y =AvgRt_sim[dt_shapes,1], color = "LOCK"), size = 2, shape=0) +
  geom_vline(xintercept=marzo8)+
  geom_vline(xintercept=maggio4)+   
  scale_x_date(date_labels = "%d %b %y", date_breaks = "2 weeks", expand = c(0,0),limits=c(Date[start],Date[TimeHoriz]))+
  #scale_y_continuous(breaks=seq(0,120,20), limits=c(0, 120))+ ### 0.8
  scale_y_continuous(breaks=seq(0.7,1.4,0.1), limits=c(0.7,1.4))+ ### 1
  theme_bw()+theme(panel.grid.minor = element_line(size=0.5)) +
  theme(axis.text.x=element_text(hjust=1,angle = 45), #  ,angle = 45
        plot.title=element_text(size=10, face="bold", margin=margin(0,0,10,0)),
        axis.title.x=element_text( margin=margin(t=5)),
        axis.title.y=element_text( margin=margin(r=5)))+
  scale_linetype(guide = FALSE)+
  guides(colour = guide_legend(override.aes = list(shape = override.shape)))+
  labs(title = TeX(paste(Title[Region],"with behavioural response;","$\\beta(m)=$", bm_Sim)), x = "", y = "", color = "Legend") +
  scale_color_manual(values = colors)+
  theme(legend.position = c(0.95, .95), legend.justification = c("right", "top"),
        legend.box.just = "left",legend.margin = margin(2, 2, 2, 2))

if (Bio_Parm=="Ferguson") {
  ggsave(paste("graphs/B_POLICIES/FERGUSON/5_POLICY_Rt_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
} else if (Bio_Parm=="CDC_mean") {
  ggsave(paste("graphs/B_POLICIES/CDC/5_POLICY_Rt_bm_",bm_Sim,"_Tinf1_",Tinf1[TimeHoriz-1],region[Region],bio[Bio_Parm],".png",sep = ""), width = 8, height = 5)
}

}}

#END